tensap.tensor\_algebra package
==============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   tensap.tensor_algebra.tensors
   tensap.tensor_algebra.tools

Module contents
---------------

.. automodule:: tensap.tensor_algebra
   :members:
   :undoc-members:
   :show-inheritance:
